@@ -19,7 +19,12 @@ has [ 'content_type', 'filename', 'url', 'code' ] => (
     is  => 'ro',
 );
 
-# make test happy, added Test::MockObject
+# make tests happy, added Test::MockObject
+if ( $INC{'Moose.pm'} ) {
+    require Moose::Util::TypeConstraints;
+    Moose::Util::TypeConstraints::class_type( 'LWP::UserAgent' );
+    Moose::Util::TypeConstraints::class_type( 'Test::MockObject' );
+}
 has 'ua' => ( is => 'ro', isa => 'LWP::UserAgent|Test::MockObject', );
 
 has 'content' => (
@@ -108,7 +113,7 @@ sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright 2009 Best Practical Solutions.
+Copyright 2009-2010 Best Practical Solutions.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
